{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "pl",
  "clipboard.copy": "Kopiuj do schowka",
  "clipboard.copied": "Skopiowane",
  "edit.link.title": "Edytuj tę stronę",
  "footer.previous": "Poprzednia strona",
  "footer.next": "Następna strona",
  "meta.comments": "Komentarze",
  "meta.source": "Kod źródłowy",
  "search.config.pipeline": " ",
  "search.placeholder": "Szukaj",
  "search.result.placeholder": "Zacznij pisać, aby szukać",
  "search.result.none": "Brak wyników wyszukiwania",
  "search.result.one": "Wyniki wyszukiwania: 1",
  "search.result.other": "Wyniki wyszukiwania: #",
  "skip.link.title": "Przejdź do treści",
  "source.link.title": "Idź do repozytorium",
  "source.revision.date": "Ostatnia aktualizacja",
  "toc.title": "Spis treści"
}[key] }}{% endmacro %}
