{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "es",
  "clipboard.copy": "Copiar al portapapeles",
  "clipboard.copied": "Copiado al portapapeles",
  "edit.link.title": "Editar esta página",
  "footer.previous": "Anterior",
  "footer.next": "Siguiente",
  "footer.title": "Pie",
  "header.title": "Cabecera",
  "meta.comments": "Comentarios",
  "meta.source": "Fuente",
  "nav.title": "Navegación",
  "search.config.lang": "es",
  "search.placeholder": "Búsqueda",
  "search.reset": "Limpiar",
  "search.result.initializer": "Inicializando búsqueda",
  "search.result.placeholder": "Teclee para comenzar búsqueda",
  "search.result.none": "No se encontraron documentos",
  "search.result.one": "1 documento encontrado",
  "search.result.other": "# documentos encontrados",
  "search.result.more.one": "1 más en esta página",
  "search.result.more.other": "# más en esta página",
  "search.result.term.missing": "Falta",
  "skip.link.title": "Saltar a contenido",
  "source.link.title": "Ir al repositorio",
  "source.revision.date": "Última actualización",
  "tabs.title": "Pestañas",
  "toc.title": "Tabla de contenidos"
}[key] }}{% endmacro %}
