{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "id",
  "clipboard.copy": "Salin ke memori",
  "clipboard.copied": "Tersalin ke memori",
  "edit.link.title": "Ubah halaman ini",
  "footer.previous": "Sebelumnya",
  "footer.next": "Selanjutnya",
  "meta.comments": "Komentar",
  "meta.source": "Sumber",
  "search.config.pipeline": " ",
  "search.placeholder": "Cari",
  "search.result.placeholder": "Ketik untuk mulai pencarian",
  "search.result.none": "Tidak ada dokumen yang sesuai",
  "search.result.one": "1 dokumen ditemukan",
  "search.result.other": "# dokumen ditemukan",
  "skip.link.title": "Lewati ke isi",
  "source.link.title": "Menuju repositori",
  "source.revision.date": "Pembaharuan Terakhir",
  "toc.title": "Daftar isi"
}[key] }}{% endmacro %}
