{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ro",
  "clipboard.copy": "Copiază în clipboard",
  "clipboard.copied": "Copiat în clipboard",
  "edit.link.title": "Editeaza această pagină",
  "footer.previous": "Anterior",
  "footer.next": "Următor",
  "meta.comments": "Comentarii",
  "meta.source": "Sursă",
  "search.config.lang": "ro",
  "search.placeholder": "Căutare",
  "search.result.placeholder": "Tastează pentru a începe căutarea",
  "search.result.none": "Nu a fost găsit niciun document",
  "search.result.one": "1 document găsit",
  "search.result.other": "# documente găsite",
  "skip.link.title": "Sari la conținut",
  "source.link.title": "Accesează repository-ul",
  "source.revision.date": "Ultima actualizare",
  "toc.title": "Cuprins"
}[key] }}{% endmacro %}
