{#-
  This file was automatically generated - do not edit
-#}
<div class="site-header-and-placeholder-wrapper">
  <div class="header-placeholder">
  </div>
  <header class="site-header">
    <div class="wrapper-1200">
      <div class="left">
        <label class="md-icon md-icon--menu md-header-nav__button" for="__drawer">
          {% include ".icons/material/menu" ~ ".svg" %}
        </label>
        <div class="site-header__main">
          <a href="https://doc.traefik.io">
            <img class="site-header__logo" alt="Load Balancer + Kubernetes Ingress + Service Mesh with Traefik and Traefik Mesh" src="{{ 'assets/images/logo-traefik-labs-logo.svg' | url }}">
          </a>
        </div>
        <nav class="site-header__nav">
          <div class="menu-item-wrapper menu-item-wrapper--dropdown">
            <a class="menu-item menu-item--with-icon">
              <span class="title">Products</span>
              <span class="icon">
                <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down">
                  <polyline points="6 9 12 15 18 9"></polyline>
                </svg>
              </span>
            </a>
            <div class="nav-dropdown-menu nav-dropdown-menu--products">
              <div class="wrapper-1200 nav-dropdown-menu-wrapper">
                <div class="nav-menu-columns nav-menu-columns--50-50">
                  <div class="nav-menu-column">
                    <div class="dm-header">Products</div>
                    <div class="dm-items">
                      <div class="dm-item dm-item--proxy">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/product-traefik-proxy.svg' | url }}" alt="Traefik Proxy">
                        </div>
                        <a href="https://traefik.io/traefik/" class="dmi-details">
                          <div class="dmi-title">Traefik Proxy</div>
                          <div class="dmi-description">
                            The cloud-native application proxy
                          </div>
                        </a>
                      </div>
                      <div class="dm-item dm-item--mesh">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/product-traefik-mesh.svg' | url }}" alt="Traefik Mesh">
                        </div>
                        <a href="https://traefik.io/traefik-mesh/" class="dmi-details">
                          <div class="dmi-title">Traefik Mesh</div>
                          <div class="dmi-description">
                            The simplest service mesh
                          </div>
                        </a>
                      </div>
                      <div class="dm-item dm-item--enterprise">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/product-traefik-enterprise.svg' | url }}" alt="Traefik Enterprise">
                        </div>
                        <a href="https://traefik.io/traefik-enterprise/" class="dmi-details">
                          <div class="dmi-title">Traefik Enterprise</div>
                          <div class="dmi-description">
                            All-in-one ingress, API management, and service mesh
                          </div>
                        </a>
                      </div>
                      <div class="dm-item dm-item--pilot">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/product-traefik-pilot.svg' | url }}" alt="Traefik Pilot">
                        </div>
                        <a href="https://traefik.io/traefik-pilot/" class="dmi-details">
                          <div class="dmi-title">Traefik Pilot</div>
                          <div class="dmi-description">
                            The Control Center for Traefik
                          </div>
                        </a>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div class="menu-item-wrapper menu-item-wrapper--dropdown">
            <a class="menu-item menu-item--with-icon">
              <span class="title">Solutions</span>
              <span class="icon">
                <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down">
                  <polyline points="6 9 12 15 18 9"></polyline>
                </svg>
              </span>
            </a>
            <div class="nav-dropdown-menu nav-dropdown-menu--solutions">
              <div class="wrapper-1200 nav-dropdown-menu-wrapper">
                <div class="nav-menu-columns nav-menu-columns--50-50">
                  <div class="nav-menu-column">
                    <div class="dm-header">Solutions</div>
                    <div class="dm-items">
                      <div class="dm-item">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/solution-kubernetes-icon.svg' | url }}" alt="Kubernetes Ingress">
                        </div>
                        <a href="https://traefik.io/solutions/kubernetes-ingress/" class="dmi-details">
                          <div class="dmi-title">Kubernetes Ingress</div>
                          <div class="dmi-description">
                            A centralized routing solution for your Kubernetes
                            deployment
                          </div>
                        </a>
                      </div>
                      <div class="dm-item">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/solution-service-mesh.svg' | url }}" alt="Service Mesh">
                        </div>
                        <a href="https://traefik.io/traefik-mesh/" class="dmi-details">
                          <div class="dmi-title">Service Mesh</div>
                          <div class="dmi-description">
                            Monitor and route your internal communications
                            easily
                          </div>
                        </a>
                      </div>
                      <div class="dm-item">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/solution-docker-swarm-ingress.svg' | url }}" alt="Docker Swarm Ingress">
                        </div>
                        <a href="https://traefik.io/solutions/docker-swarm-ingress/" class="dmi-details">
                          <div class="dmi-title">Docker Swarm Ingress</div>
                          <div class="dmi-description">
                            Powerful traffic management for your Docker Swarm
                            deployment
                          </div>
                        </a>
                      </div>
                      <div class="dm-item">
                        <div class="dmi-image">
                          <img src="{{ 'assets/images/solution-api-gateway.svg' | url }}" alt="API Gateway">
                        </div>
                        <a href="https://traefik.io/solutions/api-gateway/" class="dmi-details">
                          <div class="dmi-title">API Gateway</div>
                          <div class="dmi-description">
                            Deploy, Secure, and Manage your microservices and
                            APIs
                          </div>
                        </a>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div class="menu-item-wrapper menu-item-wrapper--dropdown">
            <a class="menu-item menu-item--with-icon">
              <span class="title">Learn</span>
              <span class="icon">
                <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down">
                  <polyline points="6 9 12 15 18 9"></polyline>
                </svg>
              </span>
            </a>
            <div class="nav-dropdown-menu nav-dropdown-menu--learn">
              <div class="wrapper-1200 nav-dropdown-menu-wrapper">
                <div class="nav-menu-columns nav-menu-columns--75-25">
                  <div class="nav-menu-column">
                    <div class="dropdown-submenu dropdown-submenu--learn">
                      <div class="dm-header">Learn</div>
                      <div class="dm-items">
                        <a href="https://traefik.io/blog/" class="dm-item"> Blog </a>
                        <a href="https://traefik.io/resources/" class="dm-item">
                          Resource Library
                        </a>
                        <a href="https://traefik.io/success-stories/" class="dm-item">
                          Success Stories
                        </a>
                        <a href="https://traefik.io/events/" class="dm-item"> Events </a>
                      </div>
                    </div>
                    <div class="dropdown-submenu dropdown-submenu--documentation">
                      <div class="dm-header">Documentation</div>
                      <div class="dm-items">
                        <a href="https://doc.traefik.io" class="dm-item">
                          Overview
                        </a>
                        <a href="https://doc.traefik.io/traefik/" class="dm-item">
                          Traefik Proxy
                        </a>
                        <a href="https://doc.traefik.io/traefik-enterprise/" class="dm-item">
                          Traefik Enterprise
                        </a>
                        <a href="https://doc.traefik.io/traefik-mesh/" class="dm-item">
                          Traefik Mesh
                        </a>
                        <a href="https://doc.traefik.io/traefik-pilot/" class="dm-item">
                          Traefik Pilot
                        </a>
                      </div>
                    </div>
                    <div class="dropdown-submenu dropdown-submenu--community">
                      <div class="dm-header">Community</div>
                      <div class="dm-items">
                        <a href="https://traefik.io/community/" class="dm-item"> Overview </a>
                        <a href="https://community.traefik.io/" class="dm-item">
                          Forum
                        </a>
                        <a href="https://info.traefik.io/traefik-ambassador-program" class="dm-item">
                          Traefik Ambassadors
                        </a>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <div class="menu-item-wrapper">
            <a href="https://traefik.io/pricing/" class="menu-item"> Pricing </a>
          </div>
          <div class="menu-item-wrapper menu-item-wrapper--dropdown">
            <a class="menu-item menu-item--with-icon">
              <span class="title">Company</span>
              <span class="icon">
                <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down">
                  <polyline points="6 9 12 15 18 9"></polyline>
                </svg>
              </span>
            </a>
            <div class="nav-dropdown-menu nav-dropdown-menu--company">
              <div class="wrapper-1200 nav-dropdown-menu-wrapper">
                <div class="nav-menu-columns nav-menu-columns--50-50">
                  <div class="nav-menu-column">
                    <div class="dropdown-submenu dropdown-submenu--company">
                      <div class="dm-header">Company</div>
                      <div class="dm-items">
                        <a href="https://traefik.io/about-us/" class="dm-item"> About </a>
                        <a href="https://traefik.io/partners/" class="dm-item"> Partners </a>
                        <a href="https://traefik.io/careers/" class="dm-item"> Careers </a>
                        <a href="https://traefik.io/press/" class="dm-item"> Press </a>
                        <a href="https://traefik.io/contact-us/" class="dm-item"> Contact Us </a>
                      </div>
                    </div>
                    <div class="dropdown-submenu dropdown-submenu--events">
                      <div class="dm-header">Events</div>
                      <div class="dm-items">
                        <a href="https://traefik.io/events/" class="dm-item"> View all events </a>
                        <a href="https://traefik.io/events/meetup/" class="dm-item"> Meetup </a>
                      </div>
                    </div>
                  </div>
                  <div class="nav-menu-column nav-menu-column--cards">
                    <div class="nav-menu-careers-card">
                      <p>Interested in joining Traefik Labs?</p>
                      <a class="button--primary button--primary--small" href="https://traefik.io/careers/#open-positions">
                        View Open Positions
                      </a>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </nav>
      </div>
      <div class="right">
        <label class="md-icon md-icon--search md-header-nav__button" for="__search">
          {% include ".icons/material/magnify.svg" %}
        </label>
        <div class="site-header__demo-button">
          <button class="button--secondary">Get a demo</button>
        </div>
      </div>
    </div>
  </header>
</div>
