{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "de",
  "clipboard.copy": "In Zwischenablage kopieren",
  "clipboard.copied": "In Zwischenablage kopiert",
  "edit.link.title": "Seite editieren",
  "footer.previous": "Zurück",
  "footer.next": "Weiter",
  "meta.comments": "Kommentare",
  "meta.source": "Quellcode",
  "search.config.lang": "de",
  "search.placeholder": "Suche",
  "search.result.initializer": "Suche wird initialisiert",
  "search.result.placeholder": "Suchbegriff eingeben",
  "search.result.none": "Keine Suchergebnisse",
  "search.result.one": "1 Suchergebnis",
  "search.result.other": "# Suchergebnisse",
  "search.result.more.one": "1 weiteres Suchergebnis auf dieser Seite",
  "search.result.more.other": "# weitere Suchergebnisse auf dieser Seite",
  "search.result.term.missing": "Es fehlt",
  "skip.link.title": "Zum Inhalt",
  "source.link.title": "Quellcode",
  "source.revision.date": "Letztes Update",
  "toc.title": "Inhaltsverzeichnis"
}[key] }}{% endmacro %}
