{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "hu",
  "clipboard.copy": "Másolás vágólapra",
  "clipboard.copied": "Vágólapra másolva",
  "edit.link.title": "Oldal szerkesztése",
  "footer.previous": "Előző",
  "footer.next": "Következő",
  "meta.comments": "Hozzászólások",
  "meta.source": "Forrás",
  "search.config.lang": "hu",
  "search.placeholder": "Keresés",
  "search.result.placeholder": "Kereséshez írj ide valamit",
  "search.result.none": "Nincs találat",
  "search.result.one": "1 egyező dokumentum",
  "search.result.other": "# egyező dokumentum",
  "skip.link.title": "Kihagyás",
  "source.link.title": "Főoldalra ugrás",
  "source.revision.date": "Utolsó frissítés",
  "toc.title": "Tartalomjegyzék"
}[key] }}{% endmacro %}
