{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "my",
  "clipboard.copy": "ကလစ်ဘုတ် သို့ ကူးယူရန်",
  "clipboard.copied": "ကလစ်ဘုတ် သို့ ကူယူပြီး",
  "edit.link.title": "ဤ စာမျက်နှာကို ပြင်ရန်",
  "footer.previous": "နောက်သို့",
  "footer.next": "ရှေ့သို့",
  "footer.title": "အောက်ခြေ",
  "header.title": "ခေါင်းပိုင်း",
  "meta.comments": "မှတ်ချက်များ",
  "meta.source": "ရင်းမြစ်",
  "nav.title": "လမ်းညွှန်",
  "search.config.pipeline": " ",
  "search.placeholder": "ရှာရန်",
  "search.reset": "ရှင်းလင်း",
  "search.result.placeholder": "ရှာဖွေခြင်းစရန် စာရိုက်ပါ",
  "search.result.none": "တူညီသော စာရွက်စာတမ်းများ မရှိပါ",
  "search.result.one": "စာရွက်စာတမ်း ၁ ခု တူညီသည်",
  "search.result.other": "စာရွက်စာတမ်း # ခု တူညီသည်",
  "skip.link.title": "မာတိကာ သို့ သွားရန်",
  "source.link.title": "repository သို့ သွားရန်",
  "source.revision.date": "နောက်ဆုံး ထုတ်ပြန်ချက်",
  "tabs.title": "တက်များ",
  "toc.title": "ပါဝင်အကြောင်းအရာများ"
}[key] }}{% endmacro %}
