{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ru",
  "clipboard.copy": "Копировать в буфер",
  "clipboard.copied": "Скопировано в буфер",
  "edit.link.title": "Редактировать страницу",
  "footer.previous": "Назад",
  "footer.next": "Вперед",
  "meta.comments": "Комментарии",
  "meta.source": "Исходный код",
  "search.config.lang": "ru",
  "search.placeholder": "Поиск",
  "search.result.placeholder": "Начните печатать для поиска",
  "search.result.none": "Совпадений не найдено",
  "search.result.one": "Найдено 1 совпадение",
  "search.result.other": "Найдено # совпадений",
  "skip.link.title": "Перейти к содержанию",
  "source.link.title": "Перейти к репозиторию",
  "source.revision.date": "Последнее обновление",
  "toc.title": "Содержание"
}[key] }}{% endmacro %}
