{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "fr",
  "clipboard.copy": "Copier dans le presse-papier",
  "clipboard.copied": "Copié dans le presse-papier",
  "edit.link.title": "Editer cette page",
  "footer.previous": "Précédent",
  "footer.next": "Suivant",
  "meta.comments": "Commentaires",
  "meta.source": "Source",
  "search.config.lang": "fr",
  "search.placeholder": "Rechercher",
  "search.result.placeholder": "Taper pour démarrer la recherche",
  "search.result.none": "Aucun document trouvé",
  "search.result.one": "1 document trouvé",
  "search.result.other": "# documents trouvés",
  "skip.link.title": "Aller au contenu",
  "source.link.title": "Aller au dépôt",
  "source.revision.date": "Dernière mise à jour",
  "toc.title": "Table des matières"
}[key] }}{% endmacro %}
