{#-
  This file was automatically generated - do not edit
-#}
{% set class = "md-nav__item" %}
{% if nav_item.active %}
  {% set class = "md-nav__item md-nav__item--active" %}
{% endif %}
{% if nav_item.children %}
  <li class="{{ class }} md-nav__item--nested">
    {% set checked = "checked" if nav_item.active %}
    <input class="md-nav__toggle md-toggle" data-md-toggle="{{ path }}" type="checkbox" id="{{ path }}" {{ checked }}>
    <label class="md-nav__link" for="{{ path }}">
      <span class="md-nav__item-title">{{ nav_item.title }}</span>
      <span class="md-nav__icon md-icon"></span>
    </label>
    <nav class="md-nav" aria-label="{{ nav_item.title }}" data-md-level="{{ level }}">
      <label class="md-nav__title" for="{{ path }}">
        <span class="md-nav__icon md-icon"></span>
        {{ nav_item.title }}
      </label>
      <ul class="md-nav__list" data-md-scrollfix>
        {% set base = path %}
        {% for nav_item in nav_item.children %}
          {% set path = base ~ "-" ~ loop.index %}
          {% set level = level + 1 %}
          {% include "partials/nav-item.html"  %}
        {% endfor %}
      </ul>
    </nav>
  </li>
{% elif nav_item == page %}
  <li class="{{ class }}">
    {% set toc = page.toc %}
    <input class="md-nav__toggle md-toggle" data-md-toggle="toc" type="checkbox" id="__toc">
    {% if toc | first is defined and "\x3ch1 id=" in page.content %}
      {% set toc = (toc | first).children %}
    {% endif %}
    {% if toc | first is defined %}
      <label class="md-nav__link md-nav__link--active" for="__toc">
        {{ nav_item.title }}
        <span class="md-nav__icon md-icon"></span>
      </label>
    {% endif %}
    <a href="{{ nav_item.url | url }}" class="md-nav__link md-nav__link--active">
      {{ nav_item.title }}
    </a>
    {% if toc | first is defined %}
      {% include "partials/toc.html" %}
    {% endif %}
  </li>
{% else %}
  <li class="{{ class }}">
    <a href="{{ nav_item.url | url }}" class="md-nav__link">
      {{ nav_item.title }}
    </a>
  </li>
{% endif %}
